@@ -11,7 +11,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
 
-our $VERSION = '0.7';
+our $VERSION = '0.71';
 
 =head1 NAME
 
@@ -61,6 +61,7 @@ an item
         'Album Artist' => 'blink-182',
         'Composer' => 'blink-182',
         'Album' => 'Dude Ranch',
+        'Grouping' => 'Alternative Rock, 00s Rock'
         'Genre' => 'Pop Punk',
         'Kind' => 'MPEG audio file',
         'Size' => 31337,
@@ -100,6 +101,7 @@ sub new {
         'Album Artist' => undef,
         'Composer' => undef,
         'Album' => undef,
+        'Grouping' => undef,
         'Genre' => undef,
         'Kind' => undef,
         'Size' => undef,
@@ -137,6 +139,7 @@ sub new {
         elsif ($param eq 'Album Artist') { albumArtist($self, $params{'Album Artist'}) }
         elsif ($param eq 'Composer') { composer($self, $params{'Composer'}) }
         elsif ($param eq 'Album') { album($self, $params{'Album'}) }
+        elsif ($param eq 'Grouping') { grouping($self, $params{'Grouping'}) }
         elsif ($param eq 'Genre') { genre($self, $params{'Genre'}) }
         elsif ($param eq 'Kind') { kind($self, $params{'Kind'}) }
         elsif ($param eq 'Size') { size($self, $params{'Size'}) }
@@ -276,6 +279,29 @@ sub album {
     return $self->{'Album'};
 } #album
 
+=head2 grouping( $grouping )
+
+Get/set the Grouping attribute for this item.
+
+Note: Grouping is intended to be used as a collection of music items below
+the level of an album (such as on a classical music release) where items
+are individual movements of a larger work.  They are more commonly
+used as a comma delimited list of tags to build smart playlists.
+
+=cut
+
+sub grouping {
+    my $self = shift;
+
+    if (@_) {
+        my $grouping = shift;
+        return carp "$grouping isn't a valid Grouping" unless ($grouping =~ /.*/);
+        $self->{'Grouping'} = $grouping;
+    }
+
+    return $self->{'Grouping'};
+} #grouping
+
 =head2 genre( $genre )
 
 Get/set the Genre attribute for this item.
@@ -734,14 +760,18 @@ L<Mac::iTunes::Library::XML>
 
 Drew Stephens <drew@dinomite.net>, http://dinomite.net
 
+=head1 CONTRIBUTORS
+
+Mark Allen <mrallen1@yahoo.com>
+
 =head1 SOURCE REPOSITORY
 
 http://mac-itunes.googlecode.com
 
 =head1 SVN INFO
 
-$Revision: 78 $
-$Date: 2009-12-30 10:33:01 -0700 (Wed, 30 Dec 2009) $
+$Revision: 80 $
+$Date: 2010-01-09 23:54:31 -0700 (Sat, 09 Jan 2010) $
 $Author: drewgstephens $
 
 =head1 COPYRIGHT AND LICENSE
